/***************************************************************************
 *   Copyright (C) 2006 by Dave Parker                                     *
 *   drp@ezeedsl.co.uk                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "fileselector.h"
#include "colour.h"
#include "font.h"
#include "sound.h"
#include "surface.h"
#include <algorithm>
#include <iostream>
#include <dirent.h>
#include <libgen.h>

using namespace std;

FileSelector::FileSelector() : current_file ( 0 ), current_dir ( "/mnt/sd/" ), callback ( NULL ), callback_data ( NULL )
{
    MakeList();
}

/**
 * Display player
 * @param s - Destination Surface
 * @param f - Font
 * @param fg - Foreground Colour
 * @param bg - Background Colour
 * @param hl - Highlight Colour for selected option
 */
void FileSelector::Render ( Surface& s, const Font& f, const Colour &fg, const Colour &bg, const Colour &hl )
{
    f.PutString ( s, 10, 20, fg, bg, current_dir );

    int w,h;
    f.GetTextSize ( "", w, h );

    for ( int i=current_file-3; i<current_file+4; i++ )
    {
        int pos = 3+i-current_file;
        Colour c ( bg );
        if ( i == current_file )
        {
            c = hl;
        }
        s.Rect ( 10, 40 - h/2 + pos * 20, 300, 20, c );
        if ( i >=0 && i<file_list.size() )
        {
            f.PutString ( s, 10, 40 + pos * 20 , fg, c, file_list[i] );
        }
    }

    f.PutString ( s, 10, 200, fg, bg, message );
}




void FileSelector::NextFile()
{
    if ( file_list.empty() ) return;

    current_file = ( current_file + 1 ) % file_list.size();
}


void FileSelector::PreviousFile()
{
    if ( file_list.empty() ) return;

    current_file = ( current_file + file_list.size() - 1 ) % file_list.size();
}



void FileSelector::MakeList()
{
    file_list.clear();
    DIR *d = opendir ( current_dir.c_str() );
    if ( d != NULL )
    {
        dirent *ent = NULL;
        while ( ( ent = readdir ( d ) ) != NULL )
        {
            string name = ent->d_name;
            if ( ent->d_type == DT_DIR )
            {
                if ( ent->d_name[0] != '.' )
                {
                    name += "/";
                    file_list.push_back ( name );
                }
            }
            else if ( ent->d_type == DT_REG )
            {
                file_list.push_back ( name );
            }
        }
        closedir ( d );
    }

    sort ( file_list.begin(), file_list.end() );
}


void FileSelector::Select()
{
    string fn = file_list[current_file];
    if ( fn.find ( '/' ) == string::npos )
    {
        cout << "Selected " << current_dir << fn << endl;
        if ( callback != NULL )
        {
            ( *callback ) ( callback_data, current_dir + fn, fn );
        }
    }
    else
    {
        // Directory
        current_dir += fn;
        MakeList();
        current_file = 0;
    }
}

void FileSelector::UpLevel()
{
    char d[current_dir.size() +1];
    strcpy ( d, current_dir.c_str() );
    string prev_dir = basename ( d );
    strcpy ( d, current_dir.c_str() );
    current_dir = dirname ( d );
    if ( current_dir != "/" )
    {
        current_dir += "/";
    }

    MakeList();
    current_file = 0;
    for ( int i=0; i<file_list.size(); i++ )
    {
        char f[file_list[i].size() +1];
        strcpy ( f, file_list[i].c_str() );
        if ( basename ( f ) == prev_dir )
        {
            current_file = i;
        }
    }
}


void FileSelector::SetCallback ( void ( *fn ) ( void*, std::string, std::string ), void* data )
{
    callback = fn;
    callback_data = data;
}


void FileSelector::SetMessage ( std::string m )
{
    message = m;
}

