/***************************************************************************
 *   Copyright (C) 2006 by Dave Parker                                     *
 *   drp@ezeedsl.co.uk                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "font.h"
#include <fstream>
#include <iostream>

using namespace std;

// Font class

/**
 * Load font from file
 * @param fn
 * @param size
 * @return
 */
Font::Font ( std::string fn, int size ) : font_size ( size )
{
    ttf = TTF_OpenFont ( fn.c_str(), size );
    if ( ttf == NULL )
    {
        cerr << "Failed to open font " << fn <<  " " << SDL_GetError() << " " << TTF_GetError() << endl;
    }
}


/**
 * Put string at x,y on Surface
 * @param dest - Destination Surface
 * @param x
 * @param y
 * @param fg - Foreground Colour
 * @param bg - Background Colour
 * @param s - String
 */
void Font::PutString ( Surface &dest, int x, int y,
                       const Colour& fg, const Colour& bg, std::string s ) const
{
    if ( s.length() > 0 )
    {
        SDL_Surface* fs = TTF_RenderText_Blended ( ttf, s.c_str(), fg.SGet() );
        if ( fs == NULL )
        {
            cerr << "fs = " << ( int ) fs << " String is (" << s << ")" << endl;
            cerr << "Failed to render font " << TTF_GetError() << endl;
            return;
        }

        if ( bg != Colour::NONE )
        {
            int w,h;
            TTF_SizeText ( ttf, s.c_str(), &w, &h );
            dest.Rect ( x, y, w, font_size, bg );
        }

        SDL_Rect dstr;
        dstr.x = x;
        dstr.y = y-4;
        SDL_BlitSurface ( fs, NULL, dest.GetSurface(), &dstr );
        SDL_FreeSurface ( fs );
    }
}


/**
 * Put character at x,y on Surface
 * @param dest - Destination Surface
 * @param x
 * @param y
 * @param fg - Foreground Colour
 * @param bg - Background Colour
 * @param c - Character
 */
void Font::PutChar ( Surface& dest, int x, int y,
                     const Colour& fg, const Colour& bg, int c )
{
    char s[2];
    s[0] = c;
    s[1] = '\0';
    PutString ( dest, x, y, fg, bg, s );
}



/**
 * Get font size
 * @return Font size
 */
int Font::GetSize() const
{
    return font_size;
}


/**
 * Get the size required to render given text
 * @param text
 * @param w - returned width
 * @param h - returned height
 */
void Font::GetTextSize ( const std::string& text, int& w, int&h ) const
{
    TTF_SizeText ( ttf, text.c_str(), &w, &h );
    h = font_size;
}
