/***************************************************************************
 *   Copyright (C) 2006 by Dave Parker                                     *
 *   drp@ezeedsl.co.uk                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "chessconfig.h"
#include <fstream>
#include <sstream>

using namespace std;

/**
 * Constructor
 * @return
 */
ChessConfig::ChessConfig()
{
}


/**
 * Destructor
 * @return
 */
ChessConfig::~ChessConfig()
{
}


/**
 * Load configuration from file
 * @param fn - File name
 */
void ChessConfig::LoadFile ( const std::string& fn )
{
    file_name = fn;

    values.clear();

    ifstream in ( file_name.c_str() );
    if ( in.good() )
    {
        while ( !in.fail() )
        {
            string name, value;
            in >> name >> value;
            if ( !in.fail() )
            {
                values[name] = value;
            }
        }
        in.close();
    }
}


/**
 * Save Configuration to file
 */
void ChessConfig::SaveFile()
{
    ofstream out ( file_name.c_str() );
    if ( out.good() )
    {
        for ( map<std::string, std::string>::iterator it = values.begin();
                it != values.end(); it++ )
        {
            out << it->first << " " << it->second << endl;
        }

        out.close();
        sync();
    }

}



/**
 * Get value as integer
 * @param n - Variable name
 * @param v - Returned value
 * @return True if the variable was found
 */
bool ChessConfig::GetValue ( const std::string& n, int& v )
{
    string s = values[n];
    if ( !s.empty() )
    {
        istringstream iss ( s );
        iss >> v;
    }
    return !s.empty();
}


/**
 * Get value as string
 * @param n - Variable name
 * @param v - Returned value
 * @return True if the variable was found
 */
bool ChessConfig::GetValue ( const std::string& n, std::string& v )
{
    v = values[n];
    return !v.empty();
}


/**
 * Set integer value
 * @param n - Variable name
 * @param v - value
 * @return
 */
void ChessConfig::SetValue ( const std::string& n, int v )
{
    ostringstream oss;
    oss << v;
    values[n] = oss.str();
}


/**
 * Set string value
 * @param n - Variable name
 * @param v - value
 * @return
 */
void ChessConfig::SetValue ( const std::string& n, const std::string& v )
{
    values[n] = v;
}
