/***************************************************************************
 *   Copyright (C) 2006 by Dave Parker                                     *
 *   drp@ezeedsl.co.uk                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef HISTORY_H
#define HISTORY_H

#include "board.h"
#include <string>

/**
* Move history
*/
class History
{
public:
    History ( int n, const Board& b, const std::string m, bool w, int lx, int ly, int x, int y );
    ~History();
    /**
     * Get move number
     * @return Move number
     */
    int GetMoveNo()
    {
        return move_no;
    }

    /**
     * Get last position
     * @param x - Returned X
     * @param y - Returned Y
      */
    void GetLastPosition ( int& x, int& y )
    {
        x = last_x;
        y = last_y;
    }

    /**
     * Get current position
     * @param x - Returned X
     * @param y - Returned Y
      */
    void GetThisPosition ( int& x, int& y )
    {
        x = this_x;
        y = this_y;
    }

    /**
     * Get board
     * @return Board
     */
    const Board& GetBoard()
    {
        return board;
    }

    /**
     * Get move
     * @return Move text
     */
    const std::string& GetMove()
    {
        return move;
    }


    /**
     * Get white's turn
     * @return true if white's turn
     */
    bool GetWhitesTurn()
    {
        return whites_turn;
    }

protected:
    int move_no;
    Board board;
    std::string move;
    bool whites_turn;
    int last_x, last_y;
    int this_x, this_y;
};

#endif
